package com.zd.laboratory.service;

import com.zd.laboratory.domain.LabCheckRecord;
import com.zd.laboratory.domain.LabCheckRecordDetailslog;
import com.zd.laboratory.domain.vo.LabCheckRecordVO;
import com.zd.laboratory.domain.vo.LabSubjectVO;

import java.util.List;
import java.util.Map;

/**
 * 隐患检查审核日志Service接口
 *
 * @author zd
 * @date 2022-03-31
 */
public interface ILabCheckRecordDetailslogService
{
    /**
     * 查询隐患检查审核日志
     *
     * @param id 隐患检查审核日志主键
     * @return 隐患检查审核日志
     */
    public LabCheckRecordDetailslog selectLabCheckRecordDetailslogById(Long id);

    /**
     * 查询隐患检查审核日志列表
     *
     * @param labCheckRecordDetailslog 隐患检查审核日志
     * @return 隐患检查审核日志集合
     */
    public List<LabCheckRecordDetailslog> selectLabCheckRecordDetailslogList(LabCheckRecordDetailslog labCheckRecordDetailslog);

    /**
     * 新增隐患检查审核日志
     *
     * @param labCheckRecordDetailslog 隐患检查审核日志
     * @return 结果
     */
    public int insertLabCheckRecordDetailslog(LabCheckRecordDetailslog labCheckRecordDetailslog);

    /**
     * 修改隐患检查审核日志
     *
     * @param labCheckRecordDetailslog 隐患检查审核日志
     * @return 结果
     */
    public int updateLabCheckRecordDetailslog(LabCheckRecordDetailslog labCheckRecordDetailslog);

    /**
     * 批量删除隐患检查审核日志
     *
     * @param ids 需要删除的隐患检查审核日志主键集合
     * @return 结果
     */
    public int deleteLabCheckRecordDetailslogByIds(Long[] ids);

    /**
     * 删除隐患检查审核日志信息
     *
     * @param id 隐患检查审核日志主键
     * @return 结果
     */
    public int deleteLabCheckRecordDetailslogById(Long id);
}
